#[non_exhaustive]pub struct PARL_IO<'a> { /* private fields */ }unstable only.Expand description
PARL_IO peripheral singleton
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Implementations
Sourceimpl PARL_IO<'_>
impl PARL_IO<'_>
Sourcepub unsafe fn steal() -> Self
pub unsafe fn steal() -> Self
Unsafely create an instance of this peripheral out of thin air.
Safety
You must ensure that you’re only using one instance of this type at a time.
Sourcepub unsafe fn clone_unchecked(&self) -> Self
pub unsafe fn clone_unchecked(&self) -> Self
Unsafely clone this peripheral reference.
Safety
You must ensure that you’re only using one instance of this type at a time.
Sourcepub fn reborrow(&mut self) -> PARL_IO<'_>
pub fn reborrow(&mut self) -> PARL_IO<'_>
Creates a new peripheral reference with a shorter lifetime.
Use this method if you would like to keep working with the peripheral after you dropped the driver that consumes this.
Sourcepub fn bind_rx_interrupt(&self, handler: InterruptHandler)
pub fn bind_rx_interrupt(&self, handler: InterruptHandler)
Binds an interrupt handler to the corresponding interrupt for this peripheral, and enables the interrupt.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn enable_rx_interrupt(&self, priority: Priority)
pub fn enable_rx_interrupt(&self, priority: Priority)
Enables the PARL_IO_RX peripheral interrupt on the given priority level.
Note that a suitable interrupt handler needs to be set up before the first interrupt
is triggered, otherwise the default handler will panic.
To set up an interrupt handler, use Self::bind_rx_interrupt or create a function that has the same (non-mangled) name as the interrupt you want to handle.
Examples
use esp_hal::interrupt::Priority;
#[unsafe(no_mangle)]
unsafe extern "C" fn PARL_IO_RX() {
// do something
}
peripherals.PARL_IO.enable_rx_interrupt(Priority::Priority1);
peripherals.PARL_IO.disable_rx_interrupt_on_all_cores();Sourcepub fn disable_rx_interrupt(&self)
pub fn disable_rx_interrupt(&self)
Disables the PARL_IO_RX peripheral interrupt handler on the current CPU core.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn disable_rx_interrupt_on_all_cores(&self)
pub fn disable_rx_interrupt_on_all_cores(&self)
Disables the PARL_IO_RX peripheral interrupt handler on all cores.
Sourcepub fn bind_tx_interrupt(&self, handler: InterruptHandler)
pub fn bind_tx_interrupt(&self, handler: InterruptHandler)
Binds an interrupt handler to the corresponding interrupt for this peripheral, and enables the interrupt.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn enable_tx_interrupt(&self, priority: Priority)
pub fn enable_tx_interrupt(&self, priority: Priority)
Enables the PARL_IO_TX peripheral interrupt on the given priority level.
Note that a suitable interrupt handler needs to be set up before the first interrupt
is triggered, otherwise the default handler will panic.
To set up an interrupt handler, use Self::bind_tx_interrupt or create a function that has the same (non-mangled) name as the interrupt you want to handle.
Examples
use esp_hal::interrupt::Priority;
#[unsafe(no_mangle)]
unsafe extern "C" fn PARL_IO_TX() {
// do something
}
peripherals.PARL_IO.enable_tx_interrupt(Priority::Priority1);
peripherals.PARL_IO.disable_tx_interrupt_on_all_cores();Sourcepub fn disable_tx_interrupt(&self)
pub fn disable_tx_interrupt(&self)
Disables the PARL_IO_TX peripheral interrupt handler on the current CPU core.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn disable_tx_interrupt_on_all_cores(&self)
pub fn disable_tx_interrupt_on_all_cores(&self)
Disables the PARL_IO_TX peripheral interrupt handler on all cores.
Sourceimpl PARL_IO<'_>
impl PARL_IO<'_>
Sourcepub const PTR: *const <PARL_IO as Deref>::Target = pac::PARL_IO::PTR
pub const PTR: *const <PARL_IO as Deref>::Target = pac::PARL_IO::PTR
Pointer to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub const fn ptr() -> *const <PARL_IO as Deref>::Target
pub const fn ptr() -> *const <PARL_IO as Deref>::Target
Return the pointer to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub const fn regs<'a>() -> &'a <PARL_IO as Deref>::Target
pub const fn regs<'a>() -> &'a <PARL_IO as Deref>::Target
Return a reference to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn register_block(&self) -> &<PARL_IO as Deref>::Target
pub fn register_block(&self) -> &<PARL_IO as Deref>::Target
Return a reference to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.